Package 'AutoNN'

Title: Automatic Neural Network Modeling for Time Series Forecasting
Description: Provides optimal combinations of input nodes and hidden neurons for fitting feedforward single-layer artificial neural networks in time series forecasting. Models are evaluated using root mean square error, mean absolute percentage error, and mean absolute error measures.
Authors: S. Vishnu Shankar [aut, cre], V. Lavanya [aut]
Maintainer: S. Vishnu Shankar <[email protected]>
License: GPL-3
Version: 0.1.0
Built: 2026-05-18 21:16:37 UTC
Source: https://github.com/cran/AutoNN

Help Index


AutoNN

Description

Automatic Neural Network Modeling for Time Series Forecasting

Usage

AutoNN(Data, IN, size, out_forecast)

Arguments

Data

Time series data used for the study

IN

Maximum number of input nodes

size

Maximum number of hidden nodes

out_forecast

Number of output periods to be predicted

Value

A list containing:

  • Best_Model

  • Final_Results

  • AutoNN_model

  • Fitted

  • Forecast

References

1. Shankar, S. V., Chandel, A., Gupta, R. K., Sharma, S., Chand, H., Aravinthkumar, A., & Ananthakrishnan, S. (2025). Comparative study on key time series models for exploring the agricultural price volatility in potato prices. Potato Research, 68(2), 1189-1207. DOI https://doi.org/10.1007/s11540-024-09776-3

Examples

ts_data  <- nottem
Model <- AutoNN(Data = ts_data , IN = 3, size = 5, out_forecast = 12)
Model